==> ofscraper-3.12.3.tar.gz: ofscraper-3.12.3/README.md <==
# Notice 
1. OF-Scraper can not bypass pay walls
2. OF-Scraper requires a subscription to the model, models can not be scraped anonymously whether free or paid
# Please Update to 3.11.6
As the API has changed older version are no longer viable

# For auth issues

https://github.com/datawhores/OF-Scraper/issues/442

# ReadMe

## Releases

[Releases Page](https://pypi.org/project/ofscraper/#history)

```Text

Docker and binary releases also availible
```

## Stable

<div style="display: inline-block">
<a href="https://pypi.org/project/ofscraper/">
<img src="https://img.shields.io/pypi/v/ofscraper.svg?color=dark_green&label=Stable-Release" alt="drawing" style="height:75px"/>
</div>
</a>

## Dev

None

## Table-of-contents

- [Description](#description)
- [Documentation](#documentation)
- [Feature Requests](#feature-requests)
- [Migrating from DC script](#migrating-from-dc-script)
- [Discord](#discord)
- [Support](#support)

## Description

command-line tool that lets you download media from OnlyFans and perform bulk actions including liking or unliking posts.

![CopyQ nsUBdI](https://user-images.githubusercontent.com/67020411/227816586-fb685959-cd3f-45af-adea-14773b7154f9.png)

At its inception, this project emerged as a fork of the original onlyfans-scraper. With invaluable support from the community and consistent script updates, we've undergone substantial architectural changes, resulting in a significantly revamped codebase compared to the original master. While some of these modifications are detailed [HERE](https://github.com/datawhores/OF-Scraper/blob/main/CHANGES.md), most are only documented in the commit history.

This script has been thoughtfully crafted to facilitate seamless transitions from DIGITALCRIMINALS' script, ensuring robust compatibility and smooth feature migration. Furthermore, it boasts an extensive array of filtering features, empowering users with precise control over the specific content types they aim to scrape

## Documentation

For detailed instructions on:

- Installation
- Running the tool
- And other pertinent information you might need

[Official Documention](https://of-scraper.gitbook.io/of-scraper)

<h3>DISCLAIMERS:</h3>
<ol>
    <li>
        This tool is not affiliated, associated, or partnered with OnlyFans in any way. We are not authorized, endorsed, or sponsored by OnlyFans. All OnlyFans trademarks remain the property of Fenix International Limited.
    </li>
    <li>
        This is a theoritical program only and is for educational purposes. If you choose to use it then it may or may not work. You solely accept full responsability and indemnify the creator, hostors, contributors and all other involved persons from any any all responsability.
    </li>
</ol>

## Issues

Open a issue in this repo, or you can mention your issue in the [Discord](#discord)

**Feature request issues are fine**
**Bug Report Issues without required material will be closed**

### Private Reports

A ticket can be created in the ticket channel
only you and admins have access to ticket discussions

## Feature Requests

[ClearFlask Feedback](https://ofscraper.clearflask.com/feedback) or [Discord](#discord)

## Migrating from DC script

To maintain compatibility with your current folders, make sure to modify the metadata option within the config file. Additionally, configure the save_path, dir_path, and filename settings to generate outputs that align with your existing setup.

The inherited metadata files from DIGITALCRIMINALS' script play a crucial role in preventing redundant downloads by acting as a check for duplicates.

For comprehensive guidance on making these adjustments, you can refer to the provided resources

1. [Migration Guide](https://of-scraper.gitbook.io/of-scraper/migrating-from-digitalcriminals-script)
2. [Config Options](https://of-scraper.gitbook.io/of-scraper/config-options)
3. [Customize Save Path](https://of-scraper.gitbook.io/of-scraper/config-options/customizing-save-path)

Ask in the discord or open an issue if you need help with what to change to accomplish this

## Discord

[Discord](https://discord.gg/wN7uxEVHRK)

## Support

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/datawhores)

<div>
      <h4>btc</h4>
    <a href="https://raw.githubusercontent.com/datawhores/OF-Scraper/main/donate/btc">
  <img src="https://github.com/datawhores/OF-Scraper/assets/67020411/c96d0c22-b015-4ffc-b09e-6f246ae10fba" alt="drawing" style="height:100px"/>
    </a>
</div>

<div>
    <h4>eth</h4>
    <a href="https://raw.githubusercontent.com/datawhores/OF-Scraper/main/donate/eth">
  <img src="https://github.com/datawhores/OF-Scraper/assets/67020411/d9df33e9-a8ac-4574-91dd-1cb5a20f7201" alt="drawing" style="height:100px"/>
    </a>
</div>

#

[![codecov](https://codecov.io/gh/datawhores/OF-Scraper/branch/main/graph/badge.svg?token=U1F1PQ7LGM)](https://codecov.io/gh/datawhores/OF-Scraper)

==> ofscraper-3.13.dev4.tar.gz: ofscraper-3.13.dev4/README.md <==
# Notice

1. OF-Scraper can not bypass pay walls
2. OF-Scraper requires a subscription to the model, models can not be scraped anonymously whether free or paid

# Please Update to 3.11.6

As the API has changed older version are no longer viable

# For auth issues

https://github.com/datawhores/OF-Scraper/issues/442

# ReadMe

## Releases

[Releases Page](https://pypi.org/project/ofscraper/#history)

```Text

Docker and binary releases also available
```

## Stable

<div style="display: inline-block">
<a href="https://pypi.org/project/ofscraper/">
<img src="https://img.shields.io/pypi/v/ofscraper.svg?color=dark_green&label=Stable-Release" alt="drawing" style="height:75px"/>
</div>
</a>

## Dev

None

## Table-of-contents

- [Description](#description)
- [Documentation](#documentation)
- [Feature Requests](#feature-requests)
- [Migrating from DC script](#migrating-from-dc-script)
- [Discord](#discord)
- [Support](#support)

## Description

command-line tool that lets you download media from OnlyFans and perform bulk actions including liking or unliking posts.

![CopyQ nsUBdI](https://user-images.githubusercontent.com/67020411/227816586-fb685959-cd3f-45af-adea-14773b7154f9.png)

At its inception, this project emerged as a fork of the original onlyfans-scraper. With invaluable support from the community and consistent script updates, we've undergone substantial architectural changes, resulting in a significantly revamped codebase compared to the original master. While some of these modifications are detailed [HERE](https://github.com/datawhores/OF-Scraper/blob/main/CHANGES.md), most are only documented in the commit history.

This script has been thoughtfully crafted to facilitate seamless transitions from DIGITALCRIMINALS' script, ensuring robust compatibility and smooth feature migration. Furthermore, it boasts an extensive array of filtering features, empowering users with precise control over the specific content types they aim to scrape

## Documentation

For detailed instructions on:

- Installation
- Running the tool
- And other pertinent information you might need

[Official Documention](https://of-scraper.gitbook.io/of-scraper)

<h3>DISCLAIMERS:</h3>
<ol>
    <li>
        This tool is not affiliated, associated, or partnered with OnlyFans in any way. We are not authorized, endorsed, or sponsored by OnlyFans. All OnlyFans trademarks remain the property of Fenix International Limited.
    </li>
    <li>
        This is a theoritical program only and is for educational purposes. If you choose to use it then it may or may not work. You solely accept full responsability and indemnify the creator, hostors, contributors and all other involved persons from any any all responsability.
    </li>
</ol>

## Issues

Open a issue in this repo, or you can mention your issue in the [Discord](#discord)

**Feature request issues are fine**
**Bug Report Issues without required material will be closed**

### Private Reports

A ticket can be created in the ticket channel
only you and admins have access to ticket discussions

## Feature Requests

[ClearFlask Feedback](https://ofscraper.clearflask.com/feedback) or [Discord](#discord)

## Migrating from DC script

To maintain compatibility with your current folders, make sure to modify the metadata option within the config file. Additionally, configure the save_path, dir_path, and filename settings to generate outputs that align with your existing setup.

The inherited metadata files from DIGITALCRIMINALS' script play a crucial role in preventing redundant downloads by acting as a check for duplicates.

For comprehensive guidance on making these adjustments, you can refer to the provided resources

1. [Migration Guide](https://of-scraper.gitbook.io/of-scraper/migrating-from-digitalcriminals-script)
2. [Config Options](https://of-scraper.gitbook.io/of-scraper/config-options)
3. [Customize Save Path](https://of-scraper.gitbook.io/of-scraper/config-options/customizing-save-path)

Ask in the discord or open an issue if you need help with what to change to accomplish this

## Discord

[Discord](https://discord.gg/wN7uxEVHRK)

## Support

[!["Buy Me A Coffee"](https://www.buymeacoffee.com/assets/img/custom_images/orange_img.png)](https://www.buymeacoffee.com/datawhores)

<div>
      <h4>btc</h4>
    <a href="https://raw.githubusercontent.com/datawhores/OF-Scraper/main/donate/btc">
  <img src="https://github.com/datawhores/OF-Scraper/assets/67020411/c96d0c22-b015-4ffc-b09e-6f246ae10fba" alt="drawing" style="height:100px"/>
    </a>
</div>

<div>
    <h4>eth</h4>
    <a href="https://raw.githubusercontent.com/datawhores/OF-Scraper/main/donate/eth">
  <img src="https://github.com/datawhores/OF-Scraper/assets/67020411/d9df33e9-a8ac-4574-91dd-1cb5a20f7201" alt="drawing" style="height:100px"/>
    </a>
</div>

#

[![codecov](https://codecov.io/gh/datawhores/OF-Scraper/branch/main/graph/badge.svg?token=U1F1PQ7LGM)](https://codecov.io/gh/datawhores/OF-Scraper)
